==> gsoap_2.8.28.orig.tar.gz: gsoap-2.8.28/gsoap/samples/magic/magic.h <==
/*
--------------------------------------------------------------------------------
gSOAP XML Web services tools
Copyright (C) 2001-2008, Robert van Engelen, Genivia, Inc. All Rights Reserved.
This software is released under one of the following two licenses:
GPL or Genivia's license for commercial use.
--------------------------------------------------------------------------------
GPL license.

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 59 Temple
Place, Suite 330, Boston, MA 02111-1307 USA

Author contact information:
engelen@genivia.com / engelen@acm.org
--------------------------------------------------------------------------------
A commercial use license is available from Genivia, Inc., contact@genivia.com
--------------------------------------------------------------------------------
*/

//gsoap ns1 service name:	magic
//gsoap ns1 service style:	rpc
//gsoap ns1 service encoding:	encoded
//gsoap ns1 service namespace:	http://websrv.cs.fsu.edu/~engelen/magic.wsdl
//gsoap ns1 service location:	http://websrv.cs.fsu.edu/~engelen/magicserver.cgi
//gsoap ns1 service documentation: Demo Magic Squares service

//gsoap ns1 schema namespace: urn:MagicSquare

typedef int xsd__int;

class vector
{ public:
  xsd__int *__ptr;
  int __size;
  struct soap *soap;
  vector();
  vector(int);
  virtual ~vector();
  void resize(int);
  int& operator[](int) const;
};

class matrix
{ public:
  vector *__ptr;
  int __size;
  struct soap *soap;
  matrix();
  matrix(int, int);
  virtual ~matrix();
  void resize(int, int);
  vector& operator[](int) const;
};

int ns1__magic(xsd__int rank, matrix *result);

==> gsoap_2.8.35.orig.tar.gz: gsoap-2.8.35/gsoap/samples/magic/magic.h <==
/*
--------------------------------------------------------------------------------
gSOAP XML Web services tools
Copyright (C) 2001-2008, Robert van Engelen, Genivia, Inc. All Rights Reserved.
This software is released under one of the following two licenses:
GPL or Genivia's license for commercial use.
--------------------------------------------------------------------------------
GPL license.

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 59 Temple
Place, Suite 330, Boston, MA 02111-1307 USA

Author contact information:
engelen@genivia.com / engelen@acm.org
--------------------------------------------------------------------------------
A commercial use license is available from Genivia, Inc., contact@genivia.com
--------------------------------------------------------------------------------
*/

//gsoap ns1 service name:	magic Magic squares
//gsoap ns1 service style:	rpc
//gsoap ns1 service encoding:	encoded
//gsoap ns1 service namespace:	http://websrv.cs.fsu.edu/~engelen/magic.wsdl
//gsoap ns1 service location:	http://websrv.cs.fsu.edu/~engelen/magicserver.cgi

//gsoap ns1 schema namespace: urn:MagicSquare

typedef int xsd__int;

// SOAP encoded array of ints
class vector
{ public:
  xsd__int *__ptr;
  int __size;
  struct soap *soap;
  vector();
  vector(int);
  virtual ~vector();
  void resize(int);
  int& operator[](int) const;
};

// SOAP encoded array of arrays of ints
class matrix
{ public:
  vector *__ptr;
  int __size;
  struct soap *soap;
  matrix();
  matrix(int, int);
  virtual ~matrix();
  void resize(int, int);
  vector& operator[](int) const;
};

//gsoap ns1 service method: magic Compute magic square of given rank
//gsoap ns1 service method: magic::rank magic square matrix rank
int ns1__magic(xsd__int rank, matrix *result);
